package Debug;

use strict;
use warnings;
use vars qw($datarefcnt $hashrefcnt $hashbux $hashused $maxdepth);

use Exporter;

@Debug::EXPORT_OK = qw(memstat timemark timestat);

@Debug::ISA = ('Exporter');

$datarefcnt=0;
$hashrefcnt=0;
$hashbux=0;
$hashused=0;
$maxdepth=0;

sub inspect
{
    my ($ref, $depth)=@_;
    $depth=0 unless(defined $depth);
    $maxdepth=$depth if( $depth > $maxdepth );
    if( ref($ref) eq 'HASH' ) {
	$hashrefcnt++;
	my ($used,$alloc)=split('/',scalar(%$ref));
	$hashbux += $alloc;
	$hashused += $used;
	foreach (values %$ref) { inspect($_,$depth+1); }
	}
    else {
	$datarefcnt++;
	}
}

sub memstat
{

    my $idxmaxlen=0;
    my $keycnt=0;

    foreach(@Data::indexes) {
	$idxmaxlen = scalar(@$_) if ( scalar(@$_) > $idxmaxlen );
	$keycnt += Data::grep( map{$_=>undef} @$_ );
	}
    my $idxcnt=scalar(@Data::indexes);
    my $aggcnt=scalar(@Data::aggregations);
    my $asscnt=scalar(@Data::associations);

    print "\nData: indexes: $idxcnt (*$aggcnt=$asscnt); maxlen: $idxmaxlen; keys: $keycnt; ";
    # datarefcnt should == keycnt * #aggregations
    inspect($Data::data);
    print "\nData hash: ref count: $hashrefcnt hash + $datarefcnt data; ";
    print "\nData hash: ";
    print "max depth: $maxdepth; ";
    print "buckets: $hashbux/$hashused used";
    print '(',int($hashused*100/$hashbux),'%)';

    if( -f "/proc/$$/status" ) {
	open(F,"< /proc/$$/status") or die "jopa with /proc/$$/status\n";
	undef $/; my $meminfo=<F>;
	close(F);
	($meminfo) = ($meminfo =~ /^(VmData.+)$/m );
	print "\n$meminfo";
	}
}

use vars qw(@timestamps);

@timestamps =( ['start', times()] );

sub timemark 
{
    my $mark = shift;
    push @timestamps, [ $mark, times() ];
}

sub timestat
{
    my @prev = @{shift @timestamps};
    my @total=('total');
    while( my $cur = shift @timestamps ) {
	my @wasted=@$cur;
	foreach (1 .. $#wasted) {
	    $wasted[$_]-=$prev[$_];
	    $total[$_]+=$wasted[$_];
	    }
	@prev=@$cur;
	printf "\nwasted: %16s: %g user, %g system", @wasted;
	}
    printf "\nwasted: %16s: %g user, %g system", @total;
}

1;
