package Html;

use strict;
use warnings;

use Exporter;
use Config qw#get_config#;
use Trans qw#translate#;

@Html::EXPORT_OK = qw(escape head foot);

@Html::ISA = ('Exporter');

=head1 Html.pm

A set of utilities used by report modules.

=cut

# NB: preserves all &foo; to allow inclusion of strange characters
#     returns list
sub escape
{
    return map {
	s/</&lt;/g;
	s/>/&gt;/g;
	s/"/&quot;/g;
	s/\s{2,}/&nbsp;/g;
	$_;
	} @_;
}

# generates only common header - with title and head.
sub head
{
	my ($title, $header) = @_;
	my $text;
	my $charset = get_config ('html_charset');
	my $stylesheet = get_config ('html_stylesheet');
	
	$text = "<html>\n<head>";
	if ($charset)
	{
		$text .= qq#\n<meta http-equiv="Content-Type" #
		.	qq#content="text/html; charset=#
		.	qq#$charset" />#;
	}
	
	if ($stylesheet)
	{
		$text .= qq#\n<link rel="stylesheet" type="text/css" #
		.	qq#href="$stylesheet" />#;
	}
	
	$text .= "\n<title>$title</title>"
	.	"\n</head>\n"
	.	"\n<body>";
	
	$text .= "\n<h1>$header</h1>\n" if $header;
	return $text;
}

sub foot
{
	my ($a, $e);
	my $text = "\n<hr />\n" .
		qq#\n<p id="footer">Generated by $::NAME $::VERSION<br /># .
		qq#\n  This program is was written by:<br />#;

	while (($a, $e) = each %::AUTHORS)
	{
		$text .= qq#\n    <a href="mailto:$e">$a</a><br />#;
	}

	$text .= qq#\n  Get the newest version from <a href="$::HOMEPAGE"># .
		$::NAME . qq#'s homepage</a>\n</p>#;
	
	$text .= "\n</body>\n</html>\n";
	return $text;
}

1;
