package Utils;

use strict;
use warnings;

use vars qw#@EXPORT_OK %EXPORT_TAGS#;
use Exporter;
use Html qw#escape#;
use Trans qw#translate#;

@Utils::ISA = qw#Exporter#;
@EXPORT_OK =
qw#
	cmp_arrays
	printgroup
	printgrouping
	printselection
	normname
	filescape
	trans
	lgrep
#;

%EXPORT_TAGS =
(
	all => [ @EXPORT_OK ]
);

sub cmp_arrays 
{
	my @A = @{$_[0]};
	my @B = @{$_[1]};
	
	return 0 if (scalar @A != scalar @B);

	while (@A && @B)
	{ 
		my $a = shift (@A);
		my $b = shift (@B);
		
		next if (!defined ($a) and !defined ($b));
		
		return (0) if (!defined ($a) or !defined ($b));

		return (0) if ($a ne $b);
	}
	return 1;
}

# used for debug/verbose messages
sub printgroup { return '('.join(' ',@_).')'; }

# used in verose/error messages
# @grouping is an array of references to groups
sub printgrouping
{
    my (@grouping)=@_;
    return join(' / ', # join groups
		map(printgroup(@$_),@grouping)
	       );
}

# used in verose/error messages
# @selection is an array of references to lists of groups
sub printselection
{
    my (@selection)=@_;    
    return join(' / ', # join subsets
		map(
		    join(' ', # join groups
			 map(printgroup(@$_),@$_)
			),
		    @selection)
		);
}

# transforms labels or whatever to internal names
# used probably in setup only
sub normname
{
    my $l=shift;
    $l=lc($l);
    $l=~s/\s+//g;
    return $l;
}

use locale;
# leaves plausible chars in filenames
# according to vim/doc/pattern.txt:405 :)
# \w should match [:alnum:] using LC_CTYPE
sub filescape
{
    $_=shift;
    s/[\s]+/_/g; 
    s/[^\w~_-]/#/g; 
    return $_;
}

# used in report module(s), or only in core.pm
sub trans
{
    return (escape(map {s/ +/&nbsp;/g;$_}
			     (translate(@_))
			))[0];
}

# Works like normal grep with eq matching
sub lgrep { my ($e,@l)=@_; return grep($_ eq $e,@l); }

1;

